@@ -603,9 +603,12 @@ void SaveBookmark(char *asNick)
 	/* Don't update dir if you move around the next time you use it. */
 	rm.noSaveDir = 1;
 
-	bmpp = (BookmarkPtr *) BSEARCH(asNick,
-		gBookmarks, gNumBookmarks,
-		sizeof(BookmarkPtr), BookmarkSearchProc);
+	if ((gNumBookmarks == 0) || (gBookmarks == NULL))
+		bmpp = NULL;
+	else
+		bmpp = (BookmarkPtr *) BSEARCH(asNick,
+			gBookmarks, gNumBookmarks,
+			sizeof(BookmarkPtr), BookmarkSearchProc);
 	if (bmpp == NULL) {
 		/* Add a new entry. */
 		rm.comment[0] = '\0';
